pub fn shine_outer_loop(
max_bits: i32,
_l3_xmin: &mut ShinePsyXmin,
ix: &mut [i32],
gr: i32,
ch: i32,
config: &mut ShineGlobalConfig,
) -> i32Expand description
Outer loop: controls masking conditions and computes best scalefac and global gain Corresponds to shine_outer_loop() in l3loop.c
The outer iteration loop controls the masking conditions of all scalefactorbands. It computes the best scalefac and global gain. This module calls the inner iteration loop.